/****************************************************************************
Copyright (c) 2008-2010 Ricardo Quesada
Copyright (c) 2010-2012 cocos2d-x.org
Copyright (c) 2011      Zynga Inc.
Copyright (c) 2013-2014 Chukong Technologies Inc.
 
http://www.cocos2d-x.org

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
****************************************************************************/
package org.cocos2dx.javascript;

import java.util.List;

import org.cocos2dx.lib.Cocos2dxActivity;
import org.cocos2dx.lib.Cocos2dxGLSurfaceView;
import org.cocos2dx.lib.Cocos2dxHelper;

import com.u8.sdk.PayParams;
import com.u8.sdk.ProductQueryResult;
import com.u8.sdk.U8Code;
import com.u8.sdk.U8SDK;
import com.u8.sdk.UserExtraData;
import com.u8.sdk.platform.U8ExitListener;
import com.u8.sdk.platform.U8InitListener;
import com.u8.sdk.platform.U8Platform;
import com.u8.sdk.verify.UToken;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.os.PowerManager;
import android.util.Log;
import android.view.KeyEvent;
import android.widget.Toast;

public class AppActivity extends Cocos2dxActivity {
	private static AppActivity app  = null;
	private PowerManager.WakeLock wakeLock = null; 
	
	@Override
	public void onCreate(Bundle savedInstanceState){
		super.onCreate(savedInstanceState);
		app=this;
		

        U8Platform.getInstance().init(this, new U8InitListener() {

            @Override
            public void onSwitchAccount(UToken data) {
                //游戏中通过SDK切换到新账号的回调，游戏收到该回调，需要引导用户重新登录，重新加载该新用户对应的角色数据   
            	Cocos2dxHelper.ledu_ssid = data.getToken();
				Cocos2dxHelper.ledu_uuid = data.getSdkUsername();
				Cocos2dxHelper.ledu_platformUserName = data.getUserID()+"";
				Cocos2dxHelper.onLeduSDKLoginStrCallBack();
        		
            	//2018-01-05
//            	Log.d("U8SDK", "Cocos2dxHelper.onGameLogoutCallback() start");
//            	Cocos2dxHelper.onGameLogoutCallback();
//            	Log.d("U8SDK", "Cocos2dxHelper.onGameLogoutCallback() end");
//            	U8Platform.getInstance().logout();
//        		U8Platform.getInstance().login(app);
            }

            @Override
            public void onPayResult(int code, String msg) {

                Log.d("U8SDK", "pay result. code:"+code+";msg:"+msg);

                switch(code){
                case U8Code.CODE_PAY_SUCCESS:
                    Toast.makeText(app, "支付成功", Toast.LENGTH_LONG).show();
                    break;
                case U8Code.CODE_PAY_FAIL:
                    Toast.makeText(app, "支付失败", Toast.LENGTH_LONG).show();
                    break;

                case U8Code.CODE_PAY_CANCEL:
                    Toast.makeText(app, "支付取消", Toast.LENGTH_LONG).show();
                    break;
                case U8Code.CODE_PAY_UNKNOWN:
                    Toast.makeText(app, "未知错误", Toast.LENGTH_LONG).show();
                    break;
                }

            }

            @Override
            public void onLogout() {
                //用户登出回调（需要收到该回调需要返回游戏登录界面，并调用login接口，打开SDK登录界面）
            	//Cocos2dxHelper.ledu_ssid = "";
				//Cocos2dxHelper.ledu_uuid = "";
				//Cocos2dxHelper.ledu_ssid = "";
				//Cocos2dxHelper.onLeduSDKLoginStrCallBack();
            	
				//2018-01-08
            	Log.d("U8SDK", "Cocos2dxHelper.onGameLogoutCallback() start");
            	Cocos2dxHelper.onGameLogoutCallback();
            	Log.d("U8SDK", "Cocos2dxHelper.onGameLogoutCallback() end");
            	
            	Cocos2dxHelper.ledu_ssid = "";
				Cocos2dxHelper.ledu_uuid = "";
				Cocos2dxHelper.ledu_ssid = "";
				Cocos2dxHelper.onLeduSDKLoginStrCallBack();
            	
				//2018-01-08
            	U8Platform.getInstance().logout();
        		U8Platform.getInstance().login(app);
            }

            //渠道SDK登录并去u8server登录认证成功，会回调改方法。
            //UToken中的参数如下：
            //userID:U8Server生成的唯一用户ID，游戏服务器需要将游戏账户ID和该userID进行绑定。
            //sdkUserID:渠道SDK平台用户唯一ID，一般不需要使用
            //username:U8Server生成的用户名，比如234234234.uc,4353453453.baidu,65756756756.360
            //sdkUserName:渠道SDK平台用户名，可能为空，部分渠道SDK没有返回用户名
            //token:U8Server生成的会话ID，游戏服务器拿该字段去U8Server做二次登录验证
            //extension:U8Server返回的扩展字段，部分渠道SDK需要，游戏中无需使用该字段的值
            //timestamp:U8Server生成的时间戳，游戏服务器去U8Server做二次登录验证时，传给U8Server            
            @Override
            public void onLoginResult(int code, UToken data) {
                switch(code){
                case U8Code.CODE_LOGIN_SUCCESS:
                	Cocos2dxHelper.ledu_ssid = data.getToken();
					Cocos2dxHelper.ledu_uuid = data.getSdkUsername();
					Cocos2dxHelper.ledu_platformUserName = data.getUserID()+"";
					Cocos2dxHelper.onLeduSDKLoginStrCallBack();
                    //进入游戏 
                    //从UToken中获取用户信息
                    break;
                case U8Code.CODE_LOGIN_FAIL:
                	Cocos2dxHelper.ledu_ssid = "";
					Cocos2dxHelper.ledu_uuid = "";
					Cocos2dxHelper.ledu_ssid = "";
                    Toast.makeText(app, "登录失败", Toast.LENGTH_LONG).show();
                    break;
                }
            }

            @Override
            public void onInitResult(int code, String msg) {
                Log.d("U8SDK", "init result.code:"+code+";msg:"+msg);
                switch(code){
                case U8Code.CODE_INIT_SUCCESS:
                    Toast.makeText(app, "初始化成功", Toast.LENGTH_LONG).show();
                    break;
                case U8Code.CODE_INIT_FAIL:
                    Toast.makeText(app, "初始化失败", Toast.LENGTH_LONG).show();
                    break;
                }
            }

			@Override
			public void onProductQueryResult(List<ProductQueryResult> arg0) {
				// TODO Auto-generated method stub
				
			}
        });
	}
	
	public void initLeduSDK()
	{
		 U8Platform.getInstance().login(this);
	}
	public void switchLeduPassport()
	{
		U8Platform.getInstance().logout();
		U8Platform.getInstance().login(this);
	}
	public void payOrder(String server_id,String platformUserName,int money,String extra,String desc)
	{
		PayParams params = new PayParams();
        params.setBuyNum(1);        //购买数量，固定1
        params.setCoinNum(100);     //当前玩家身上拥有的游戏币数量
        params.setExtension(extra); //游戏自定义数据，充值成功，回调游戏服的时候，会原封不动返回
        params.setPrice(money);         //单位 整数 元
        params.setProductId(desc);   //产品ID 2018-01-05
        params.setProductName("元宝");    //产品名称
        params.setProductDesc(desc);   //产品描述
        params.setRoleId("1");      //角色ID
        params.setRoleLevel(1);     //角色等级
        params.setRoleName(platformUserName);    //角色名称
        params.setServerId(server_id);       //服务器ID
        params.setServerName(server_id);     //服务器名称
        params.setVip("0");          //角色VIP等级
        params.setPayNotifyUrl("https://port.rxsgfk.ledu.com/pay_callback_u8android.php"); //支付成功，U8Server异步通知该地址，告诉游戏服务器发货

        U8Platform.getInstance().pay(this, params);
	}
    public void tostMsg(String msg)
    {
    	 Toast.makeText(this, msg, Toast.LENGTH_LONG).show();  
    }
    
    public void submitExtraData(int dataType,String role_id,String role_name,int server_id,String server_name){
        UserExtraData data = new UserExtraData();
        data.setDataType(dataType);
        data.setMoneyNum(0);
        data.setRoleCreateTime(0);
        data.setRoleID(role_id);
        data.setRoleName(role_name);
        data.setRoleLevel("1");
        data.setRoleLevelUpTime(0);
        data.setServerID(server_id);
        data.setServerName(server_name);
        U8Platform.getInstance().submitExtraData(data);
    }
    
    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data){
        U8SDK.getInstance().onActivityResult(requestCode, resultCode, data);
        super.onActivityResult(requestCode, resultCode, data);
    }
	
    @Override
    public Cocos2dxGLSurfaceView onCreateView() {
        Cocos2dxGLSurfaceView glSurfaceView = new Cocos2dxGLSurfaceView(this);
        // TestCpp should create stencil buffer
        glSurfaceView.setEGLConfigChooser(5, 6, 5, 0, 16, 8);

        return glSurfaceView;
    }
    private long mkeyTime = 0;  
    public boolean onKeyDown(int keyCode, KeyEvent event) {  
        if (keyCode == KeyEvent.KEYCODE_BACK) {  
        	U8Platform.getInstance().exitSDK(new U8ExitListener() {

                @Override
                public void onGameExit() {

                    //游戏自己的退出确认框
                    AlertDialog.Builder builder = new AlertDialog.Builder(app);
                    builder.setTitle("退出确认");
                    builder.setMessage("主公，现在还早，要不要再玩一会？");
                    builder.setCancelable(true);
                    builder.setPositiveButton("好吧",
                            new DialogInterface.OnClickListener() {
                                public void onClick(DialogInterface dialog,
                                        int whichButton) {
                                    //这里什么都不用做
                                }
                            });
                    builder.setNeutralButton("一会再玩",
                            new DialogInterface.OnClickListener() {
                                public void onClick(DialogInterface dialog,
                                        int whichButton) {
                                    //退出游戏
                                	app.finish();
                                    System.exit(0);
                                }
                            });
                    builder.show(); 

                }
            }); 
            return false;  
        }  
        return super.onKeyDown(keyCode, event);  
    }  
    
    @Override
    public void onStart(){
        U8SDK.getInstance().onStart();
        super.onStart();
    }
    
    @Override  
    public void onResume() {
    	U8SDK.getInstance().onResume();
        super.onResume();    
        acquireWakeLock(this);  
        
    }  
  
    @Override  
    public void onPause() { 
    	U8SDK.getInstance().onPause();
        super.onPause();  
        releaseWakeLock();  
        
    }  
  
    @Override 
    public void onNewIntent(Intent newIntent){
        U8SDK.getInstance().onNewIntent(newIntent);
        super.onNewIntent(newIntent);
    }
    @Override 
    public void onStop(){
        U8SDK.getInstance().onStop();
        super.onStop();
    }
    @Override 
    public void onDestroy(){
        U8SDK.getInstance().onDestroy();
        super.onDestroy();
    }
    @Override 
    public void onRestart(){
        U8SDK.getInstance().onRestart();
        super.onRestart();
    }
    @Override 
    public void onConfigurationChanged(Configuration newConfig){
        super.onConfigurationChanged(newConfig);
    }
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults){
        U8SDK.getInstance().onRequestPermissionResult(requestCode, permissions, grantResults);
    }
    public void acquireWakeLock(Context context) {  
        if (wakeLock == null) {  
            PowerManager powerManager = (PowerManager) (context  
                    .getSystemService(Context.POWER_SERVICE));  
            wakeLock = powerManager.newWakeLock(  
                    PowerManager.SCREEN_DIM_WAKE_LOCK, "My Tag");  
            wakeLock.acquire();  
        }  
    }  
  

    public void releaseWakeLock() {  
        if (wakeLock != null && wakeLock.isHeld()) {  
            wakeLock.release();  
            wakeLock = null;  
        }  
    }
}
